<?php
/**
 * PEAR_Installer_Role_Web
 *
 * PHP versions 4 and 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   pear
 * @package    PEAR
 * @author     Tobias Schlitt <toby@php.net>
 * @copyright  1997-2005 The PHP Group
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id: Php.php,v 1.5 2005/07/28 16:51:53 cellog Exp $
 * @link       http://pear.php.net/package/PEAR
 */

/**
 * @category   pear
 * @package    PEAR
 * @author     Tobias Schlitt <toby@php.net>
 * @copyright  1997-2005 The PHP Group
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    Release: 1.4.2
 * @link       http://pear.php.net/package/PEAR
 */
class PEAR_Installer_Role_Web extends PEAR_Installer_Role_Common
{
    /**
     * Called by the PEAR installer to retreive information on the file role. 
     * This returns static information about the file role.
     * 
     * @access public
     * @return array Information required.
     */
    function getInfo()
    {
        return array(
            // Which releases my use this role?
            'releasetypes' => array('php'),
            // Are files tagged with this role installable?
            'installable' => true,
            // What is the configuration name for the file role directory?
            'locationconfig' => 'web_dir',
            // Shall the baseinstalldir config be honored?
            'honorsbaseinstall' => true,
            // Do we use an unusual location?
            'unusualbaseinstall' => true,
            // Does the file role hold PHP files (shall theses files be
            // syntax checked?)
            'phpfile' => true,
            // Shall the files be marked as executeable?
            'executable' => false,
            // Does the file role describe files from a PHP extension in C?
            'phpextension' => false,
        );
    }

    /**
     * Set up the file role
     * This method is called by the installer to set up the file role object.
     * We don't utilize this method, for simplicity.
     * 
     * @param mixed $installer 
     * @param mixed $pkg 
     * @param mixed $atts 
     * @param mixed $file 
     * @access public
     * @return void
     */
    function setup(&$installer, $pkg, $atts, $file)
    {
    }
    
    /**
     * Returns the new config values for the installer.
     * This method returns an array to indicate additional configuration options
     * which get available when installing the custom file role.
     * 
     * @access public
     * @return void
     */
    function getSupportingConfigVars()
    {
        return array(
            // Our new config varibale is named "web_dir" (in reflection of php_dir, data_dir,...)
            'web_dir' => array(
                // What is indicated by the config value?
                'type' => 'directory',
                // Default value (should be adjusted by the user)
                'default' => '/var/www',
                // Help information
                'doc' => 'Directory where web acessable PHP files are stored.',
                // Short description
                'prompt' => 'PHP web directory',
                // Configuration group in PEAR Installers overview ("$ pear config-show")
                'group' => 'File Locations',
            ),
        );
    }
}
