<?php
/**
 * Generation script for PEAR package.xml file.
 * Generates a version 2 package.xml file using the package
 * PEAR_PackageFileManager.
 *
 * @link http://pear.php.net/package/PEAR_PackageFileManager
 *
 * PHP versions 4 and 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   Applications
 * @package    Serendipity
 * @author     Tobias Schlitt <toby@php.net>
 * @copyright  1997-2005 The PHP Group
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id: Php.php,v 1.5 2005/07/28 16:51:53 cellog Exp $
 * @link       http://www.s9y.org
 */
	
    /**
     * Package file manager for package.xml 2.
     */
    require_once 'PEAR/PackageFileManager2.php';
    
    /**
     * Some help functions.
     */
    require_once 'generate_package_xml_functions.php';

	// Directory where the package files are located.
	$packagedir  = dirname(__FILE__).'/serendipity/';

    // Name of the channel, this package will be distributed through
    $channel     = 'pear.schlitt.info';
    
    // Category and name of the package
	$category    = 'Applications';
    $package     = 'Serendipity';

    // Version (S9Y version is 0.9, I added .0 to reflect PEAR version scheme)
	$version     = '0.9.0';
	
    // Summary description
	$summary     = <<<EOT
Serendipity is a weblog/blog system, implemented with PHP. It is standards compliant,
feature rich and open source ( BSD License).
EOT;
	
    // Longer description
	$description = <<<EOT
Serendipity is a weblog/blog system, implemented with PHP. It is standards compliant,
feature rich and open source (BSD License).

Serendipity is constantly under active development, with a team of talented developers
trying to make the best PHP powered blog on the net.

Serendipity has so far also proven 100% PHP5 compatible.
EOT;

    // License information
    $license = 'BSD';
	
    // Notes, function to grab them directly from S9Y in
    // generate_package_xml_functions.php
	$notes = retreiveSerendipityNotes($packagedir);

    // Instanciate package file manager
	$pkg = new PEAR_PackageFileManager2;
    
    // Setting options
	$e = $pkg->setOptions(
		array(
            // Where are our package files.
            'packagedirectory'  => $packagedir,
            // Where will package files be installed in
            // the local PEAR repository?
            'baseinstalldir'    => 'Serendipity',
            // Where should the package file be generated
            'pathtopackagefile' => $packagedir,
            // Just simple output, no MD5 sums and <provides> tags
            'simpleoutput'      => true,
            // Use standard file list generator, choose CVS, if you
            // have your code in CVS
            'filelistgenerator' => 'file',

            // List of files to ignore and put not explicitly into the package
		    'ignore'            => 
            array(
                'package.xml',
                'package2.xml',
                'generate_package_xml.php',
                'generate_package_xml_functions.php',
                '*.tgz',
		    ),
            
            // Global mapping of directories to file roles.
            // @see http://pear.php.net/manual/en/guide.migrating.customroles.defining.php
            'dir_roles'         =>
            array( 
                'docs'                     => 'doc',
                
                'include'                  => 'php',
                'lang'                     => 'php',
                'plugins'                  => 'php',
                
                'htmlarea'                 => 'web',
                'templates'                => 'web',
                'templates_c'              => 'web',
                
                'sql'                      => 'data',
                
                'bundled-libs/docs'        => 'doc',
                'htmlarea/examples'        => 'doc',
                
                'bundled-libs/tests'       => 'test',
            ),

            // Define exceptions of previously defined role mappings,
            // this part uses real file names and no directories.
            'exceptions'        =>
            array( 
                'comment.php'	                        => 'web',
                'exit.php'	                            => 'web',
                'index.php'	                            => 'web',
                'serendipity_admin.php'	                => 'web',
                'serendipity_admin_image_selector.php'	=> 'web',
                'serendipity_config.inc.php'	        => 'web',
                'serendipity_editor.js'	                => 'web',
                'serendipity_xmlrpc.php'	            => 'web',
                'wfwcomment.php'	                    => 'web',

                'COPYING.lib'                           => 'doc',
            ),
	    )
    );

    // PEAR error checking
    if (PEAR::isError($e)) {
        die($e->getMessage());
    }
    
    // Set misc package information 
    $pkg->setPackage($package);
    $pkg->setSummary($summary);
    $pkg->setDescription($description);
    $pkg->setChannel($channel);
    
    $pkg->setReleaseStability('beta');
    $pkg->setAPIStability('stable');
    $pkg->setReleaseVersion($version);
    $pkg->setAPIVersion($version);
    
    $pkg->setLicense($license);
    $pkg->setNotes($notes);
    
    // Our package contains PHP files (not C extension files)
    $pkg->setPackageType('php');
    
    // Must be available in new package.xml format
    $pkg->setPhpDep('4.3.0');
    $pkg->setPearinstallerDep('1.4.2');

    // Require custom file role for our web installation
    $pkg->addPackageDepWithChannel('required', 'CustomInstallerFiles', 'pear.schlitt.info');

    // Require PEAR_DB package for initializing the database in the post install script
    $pkg->addPackageDepWithChannel('required', 'DB', 'pear.php.net', '1.2.0');
    
    // Insert path to our include files into S9Y global configuration
    $pkg->addReplacement('serendipity_config.inc.php', 'pear-config', '@php_dir@', 'php_dir');

    // Insert path to PEAR data dir into post install script
    $pkg->addReplacement('Setup.php', 'pear-config', '@data_dir@', 'data_dir');
    
    // Define that we will use our custom file role in this script
    $e = $pkg->addUsesRole('web', 'Webfiles');
    if (PEAR::isError($e)) {
        die($e->getMessage());
    }

    // Mapping misc roles to file name extensions
    // Directly here, a dirty hack: Map all files without extension
    // to "doc" role
    $e = $pkg->addRole('', 'doc');
    if (PEAR::isError($e)) {
        die($e->getMessage());
    }
    $e = $pkg->addRole('lib', 'doc');
    if (PEAR::isError($e)) {
        die($e->getMessage());
    }
    
    $e = $pkg->addRole('png', 'web');
    if (PEAR::isError($e)) {
        die($e->getMessage());
    }
    $e = $pkg->addRole('gif', 'web');
    if (PEAR::isError($e)) {
        die($e->getMessage());
    }
    $e = $pkg->addRole('jpeg', 'web');
    if (PEAR::isError($e)) {
        die($e->getMessage());
    }

    // Create the current release and add it to the package definition
    $pkg->addRelease();

    // Package release needs a maintainer
	$pkg->addMaintainer('lead', 'toby', 'Tobias Schlitt', 'toby@php.net');

    // Internally generate the XML for our package.xml (does not perform output!)
    $test = $pkg->generateContents();
    
    // If called without "make" parameter, we just want to debug the generated
    // package.xml file and want to receive additional information on error.
	if (isset($argv[1]) && $argv[1] === 'make') {
    	$e = $pkg->writePackageFile();
	} else {
    	$e = $pkg->debugPackageFile();
	}
	
	if (PEAR::isError($e)) {
    	echo $e->getMessage();
	}
	
?>
