<?php
/**
 * Help functions for generate_package_xml.php
 *
 * PHP versions 4 and 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   Applications
 * @package    Serendipity
 * @author     Tobias Schlitt <toby@php.net>
 * @copyright  1997-2005 The PHP Group
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id: Php.php,v 1.5 2005/07/28 16:51:53 cellog Exp $
 * @link       http://www.s9y.org
 */

    /**
     * Retreive and parse S9Y change log.
     * Fetches the NEWS file from serendipity/docs/ and parses the top most
     * messages from it, to be used in generate_package_xml.php.
     * 
     * @param string $baseDir The path to extracted S9Y sources.
     * @access public
     * @return string The top most changes.
     */
    function retreiveSerendipityNotes($baseDir)
    {
        $newsPath = $baseDir . 'docs/NEWS';
        if (!file_exists($newsPath)) {
            trigger_error('Serendipity NEWS file not found in: <'.$newsPath.'>.', E_USER_ERROR);
        }
        $newsArray = file($newsPath);
        
        $grab = false;
        $notesArray = array();
        foreach ($newsArray as $lineNo => $line) {
            $line = trim($line);
            if ((substr($line, 0, 1) === '-') && $grab === false) {
                $grab = true;
                continue;
            }
            if ($grab === true) {
                if (substr($line, 0, 1) === '-') {
                    break;
                }
                if ($line !== '') {
                    $notesArray[] = trim($line);
                }
            }
        }
        array_pop($notesArray);
        return implode("\n", $notesArray);
    }
